pub struct DiffRenderer { /* private fields */ }Expand description
Renders graph and linear views with range annotations.
Implementations
Sourceimpl DiffRenderer
impl DiffRenderer
Sourcepub fn add_range_annotation(&self, annotation: SimilarityRangeAnnotation)
pub fn add_range_annotation(&self, annotation: SimilarityRangeAnnotation)
Adds a range annotation to later renders.
NOTE: Empty ranges are ignored.
Sourcepub fn render_function(
&self,
context: &SimilarityRenderContext,
function: &Function,
)
pub fn render_function( &self, context: &SimilarityRenderContext, function: &Function, )
Renders the graph and linear views for a function.
Sourcepub fn render_function_for_entity(
&self,
context: &SimilarityRenderContext,
function: &Function,
entity: SimilarityEntityRef,
)
pub fn render_function_for_entity( &self, context: &SimilarityRenderContext, function: &Function, entity: SimilarityEntityRef, )
Renders graph and linear views for a function and session entity.
Sourcepub fn render_flow_graph(
&self,
context: &SimilarityRenderContext,
group: &str,
graph: &FlowGraph,
)
pub fn render_flow_graph( &self, context: &SimilarityRenderContext, group: &str, graph: &FlowGraph, )
Renders an annotated flow graph.
Sourcepub fn render_flow_graph_for_entity(
&self,
context: &SimilarityRenderContext,
group: &str,
graph: &FlowGraph,
entity: SimilarityEntityRef,
)
pub fn render_flow_graph_for_entity( &self, context: &SimilarityRenderContext, group: &str, graph: &FlowGraph, entity: SimilarityEntityRef, )
Renders an annotated flow graph for a session entity.
Sourcepub fn render_linear_view(
&self,
context: &SimilarityRenderContext,
group: &str,
data: &BinaryView,
linear_view: &LinearViewObject,
)
pub fn render_linear_view( &self, context: &SimilarityRenderContext, group: &str, data: &BinaryView, linear_view: &LinearViewObject, )
Renders an annotated linear view.
Sourcepub fn render_linear_view_for_entity(
&self,
context: &SimilarityRenderContext,
group: &str,
data: &BinaryView,
linear_view: &LinearViewObject,
entity: SimilarityEntityRef,
)
pub fn render_linear_view_for_entity( &self, context: &SimilarityRenderContext, group: &str, data: &BinaryView, linear_view: &LinearViewObject, entity: SimilarityEntityRef, )
Renders an annotated linear view for a session entity.