pub struct SimilarityRenderContext { /* private fields */ }Expand description
Holds the views used to display a similarity result.
Implementations
Sourceimpl SimilarityRenderContext
impl SimilarityRenderContext
pub unsafe fn from_raw(handle: *mut BNSimilarityRenderContext) -> Self
pub unsafe fn ref_from_raw(handle: *mut BNSimilarityRenderContext) -> Ref<Self>
Sourcepub fn set_preferred_view_type(&self, view_type: FunctionViewType)
pub fn set_preferred_view_type(&self, view_type: FunctionViewType)
Sets the function representation preferred by renderers writing to this context.
Sourcepub fn preferred_view_type(&self) -> FunctionViewType
pub fn preferred_view_type(&self) -> FunctionViewType
Returns the function representation preferred by renderers writing to this context.
Sourcepub fn add_flow_graph(&self, group: &str, graph: &FlowGraph)
pub fn add_flow_graph(&self, group: &str, graph: &FlowGraph)
Adds a flow graph to a view group.
Sourcepub fn add_flow_graph_for_entity(
&self,
group: &str,
graph: &FlowGraph,
entity: SimilarityEntityRef,
)
pub fn add_flow_graph_for_entity( &self, group: &str, graph: &FlowGraph, entity: SimilarityEntityRef, )
Adds a flow graph for a session entity to a view group.
Sourcepub fn add_linear_view(
&self,
group: &str,
data: &BinaryView,
linear_view: &LinearViewObject,
)
pub fn add_linear_view( &self, group: &str, data: &BinaryView, linear_view: &LinearViewObject, )
Adds a linear view to a view group.
Sourcepub fn add_linear_view_for_entity(
&self,
group: &str,
data: &BinaryView,
linear_view: &LinearViewObject,
entity: SimilarityEntityRef,
)
pub fn add_linear_view_for_entity( &self, group: &str, data: &BinaryView, linear_view: &LinearViewObject, entity: SimilarityEntityRef, )
Adds a linear view for a session entity to a view group.
Sourcepub fn views(&self) -> Vec<SimilarityView>
pub fn views(&self) -> Vec<SimilarityView>
Returns the views in insertion order.